@@ -11,7 +11,7 @@ use strict;
 use warnings;
 
 package Dist::Zilla::Plugin::CompileTests;
-our $VERSION = '1.100160';
+our $VERSION = '1.100220';
 # ABSTRACT: common tests to check syntax of your modules
 
 use Moose;
@@ -21,8 +21,8 @@ with    'Dist::Zilla::Role::FileMunger';
 
 # -- attributes
 
-# skiplist - a regex
-has skip => ( is=>'ro', predicate=>'has_skip' );
+has fake_home => ( is=>'ro', predicate=>'has_fake_home' );
+has skip      => ( is=>'ro', predicate=>'has_skip' ); # skiplist - a regex
 
 
 # -- public methods
@@ -33,13 +33,18 @@ sub munge_file {
 
     return unless $file->name eq 't/00-compile.t';
 
-    my $replacement = ( $self->has_skip && $self->skip )
+    my $skip = ( $self->has_skip && $self->skip )
         ? sprintf( 'return if $found =~ /%s/;', $self->skip )
         : '# nothing to skip';
 
-    # replace the string in the file
+    my $home = ( $self->has_fake_home && $self->fake_home )
+        ? ''
+        : '# no fake requested ##';
+
+    # replace strings in the file
     my $content = $file->content;
-    $content =~ s/COMPILETESTS_SKIP/$replacement/;
+    $content =~ s/COMPILETESTS_SKIP/$skip/;
+    $content =~ s/COMPILETESTS_FAKE_HOME/$home/;
     $file->content( $content );
 }
 
@@ -59,64 +64,93 @@ Dist::Zilla::Plugin::CompileTests - common tests to check syntax of your modules
 
 =head1 VERSION
 
-version 1.100160
+version 1.100220
+
+=for Pod::Coverage::TrustPod munge_file
 
 =head1 SYNOPSIS
 
+
 In your dist.ini:
 
+
     [CompileTests]
-    skip = Test$
+    skip      = Test$
+    fake_home = 1
 
 =head1 DESCRIPTION
 
+
 This is an extension of L<Dist::Zilla::Plugin::InlineFiles>, providing
 the following files:
 
+
 =over 4
 
+
 =item * t/00-compile.t - a standard test to check syntax of bundled modules
 
+
 This test will find all modules and scripts in your dist, and try to
 compile them one by one. This means it's a bit slower than loading them
 all at once, but it will catch more errors.
 
+
 =back
 
+
 This plugin accepts the following options:
 
+
 =over 4
 
+
 =item * skip: a regex to skip compile test for modules matching it. The
 match is done against the module name (C<Foo::Bar>), not the file path
 (F<lib/Foo/Bar.pm>).
 
-=back
 
-=for Pod::Coverage::TrustPod munge_file
+=item * fake_home: a boolean to indicate whether to fake $ENV{HOME}.
+This may be needed if your module unilateraly creates stuff in homedir:
+indeed, some cpantesters will smoke test your dist with a read-only home
+directory. Default to false.
+
+
+=back
 
 =head1 SEE ALSO
 
+
 You can also look for information on this module at:
 
+
 =over 4
 
+
 =item * AnnoCPAN: Annotated CPAN documentation
 
+
 L<http://annocpan.org/dist/Dist-Zilla-Plugin-CompileTests>
 
+
 =item * CPAN Ratings
 
+
 L<http://cpanratings.perl.org/d/Dist-Zilla-Plugin-CompileTests>
 
+
 =item * Open bugs
 
+
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Dist-Zilla-Plugin-CompileTests>
 
+
 =item * Git repository
 
+
 L<http://github.com/jquelin/dist-zilla-plugin-compiletests.git>.
 
+
 =back
 
 =head1 AUTHOR
@@ -164,7 +198,7 @@ plan tests => scalar(@modules) + scalar(@scripts);
 
 {
     # fake home for cpan-testers
-    local $ENV{HOME} = tempdir( CLEANUP => 1 );
+    COMPILETESTS_FAKE_HOME local $ENV{HOME} = tempdir( CLEANUP => 1 );
 
     is( qx{ $^X -Ilib -M$_ -e "print '$_ ok'" }, "$_ ok", "$_ loaded ok" )
         for sort @modules;
